==> ejc-wzxt-impl-3.0.0-20200925.074511-8-sources.jar: com/ejianc/business/wzxt/bean/OrderDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 订单明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_order_detail")
public class OrderDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="detail_index")
    private java.lang.String detailIndex; // 序号
    @TableField(value="parent_id")
    private java.lang.Long parentId; // parent_id
    @TableField(value="leaf_flag")
    private java.lang.Integer leafFlag; // 是否末级
    @TableField(value="order_id")
    private java.lang.Long orderId; // 订单主键ID
    @TableField(value="plan_id")
    private java.lang.Long planId; // 计划主键ID
    @TableField(value="plan_detail_id")
    private java.lang.Long planDetailId; // 计划明细主键ID
    @TableField(value="plan_name")
    private java.lang.String planName; // 使用计划名称
    @TableField(value="plan_bill_code")
    private java.lang.String planBillCode; // 计划编码
    @TableField(value="plan_employee_name")
    private java.lang.String planEmployeeName; // 计划编制人
    @TableField(value="construction")
    private java.lang.String construction; // 施工部位
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="plan_nums_sum")
    private java.math.BigDecimal planNumsSum; // 计划数量
    @TableField(value="receive_nums_sum")
    private java.math.BigDecimal receiveNumsSum; // 接收数量
    @TableField(value="surplus_nums_sum")
    private java.math.BigDecimal surplusNumsSum; // 计划剩余数量
    @TableField(value="order_nums_sum")
    private java.math.BigDecimal orderNumsSum; // 订单数量
    @TableField(value="deliver_nums_sum")
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    @TableField(value="check_nums_sum")
    private java.math.BigDecimal checkNumsSum; // 验收数量
    @TableField(value="material_manufacturer")
    private java.lang.String materialManufacturer; // 生产厂家
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    
    
    

    /**
     * 序号
     */
    public java.lang.String getDetailIndex() {
        return detailIndex;
    }

    /**
     * 序号
     */
    public void setDetailIndex(java.lang.String detailIndex) {
        this.detailIndex = detailIndex;
    }
    /**
     * parent_id
     */
    public java.lang.Long getParentId() {
        return parentId;
    }

    /**
     * parent_id
     */
    public void setParentId(java.lang.Long parentId) {
        this.parentId = parentId;
    }
    /**
     * 是否末级
     */
    public java.lang.Integer getLeafFlag() {
        return leafFlag;
    }

    /**
     * 是否末级
     */
    public void setLeafFlag(java.lang.Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 计划主键ID
     */
    public java.lang.Long getPlanId() {
        return planId;
    }

    /**
     * 计划主键ID
     */
    public void setPlanId(java.lang.Long planId) {
        this.planId = planId;
    }
    /**
     * 计划明细主键ID
     */
    public java.lang.Long getPlanDetailId() {
        return planDetailId;
    }

    /**
     * 计划明细主键ID
     */
    public void setPlanDetailId(java.lang.Long planDetailId) {
        this.planDetailId = planDetailId;
    }
    /**
     * 使用计划名称
     */
    public java.lang.String getPlanName() {
        return planName;
    }

    /**
     * 使用计划名称
     */
    public void setPlanName(java.lang.String planName) {
        this.planName = planName;
    }
    /**
     * 计划编码
     */
    public java.lang.String getPlanBillCode() {
        return planBillCode;
    }

    /**
     * 计划编码
     */
    public void setPlanBillCode(java.lang.String planBillCode) {
        this.planBillCode = planBillCode;
    }
    /**
     * 计划编制人
     */
    public java.lang.String getPlanEmployeeName() {
        return planEmployeeName;
    }

    /**
     * 计划编制人
     */
    public void setPlanEmployeeName(java.lang.String planEmployeeName) {
        this.planEmployeeName = planEmployeeName;
    }
    /**
     * 施工部位
     */
    public java.lang.String getConstruction() {
        return construction;
    }

    /**
     * 施工部位
     */
    public void setConstruction(java.lang.String construction) {
        this.construction = construction;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计划数量
     */
    public java.math.BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    /**
     * 计划数量
     */
    public void setPlanNumsSum(java.math.BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }
    /**
     * 接收数量
     */
    public java.math.BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    /**
     * 接收数量
     */
    public void setReceiveNumsSum(java.math.BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    /**
     * 计划剩余数量
     */
    public java.math.BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    /**
     * 计划剩余数量
     */
    public void setSurplusNumsSum(java.math.BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }
    /**
     * 订单数量
     */
    public java.math.BigDecimal getOrderNumsSum() {
        return orderNumsSum;
    }

    /**
     * 订单数量
     */
    public void setOrderNumsSum(java.math.BigDecimal orderNumsSum) {
        this.orderNumsSum = orderNumsSum;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}

==> ejc-wzxt-impl-3.0.0-20201028.032715-67-sources.jar: com/ejianc/business/wzxt/bean/OrderDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 订单明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_order_detail")
public class OrderDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="detail_index")
    private java.lang.String detailIndex; // 序号
    @TableField(value="parent_id")
    private java.lang.Long parentId; // parent_id
    @TableField(value="tid")
    private java.lang.Long tid; // tid
    @TableField(value="leaf_flag")
    private Boolean leafFlag; // 是否末级
    @TableField(value="order_id")
    private java.lang.Long orderId; // 订单主键ID
    @TableField(value="plan_id")
    private java.lang.Long planId; // 计划主键ID
    @TableField(value="plan_detail_id")
    private java.lang.Long planDetailId; // 计划明细主键ID
    @TableField(value="plan_name")
    private java.lang.String planName; // 使用计划名称
    @TableField(value="plan_bill_code")
    private java.lang.String planBillCode; // 计划编码
    @TableField(value="plan_employee_name")
    private java.lang.String planEmployeeName; // 计划编制人
    @TableField(value="construction")
    private java.lang.String construction; // 施工部位
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="plan_nums_sum")
    private java.math.BigDecimal planNumsSum; // 计划数量
    @TableField(value="receive_nums_sum")
    private java.math.BigDecimal receiveNumsSum; // 接收数量
    @TableField(value="surplus_nums_sum")
    private java.math.BigDecimal surplusNumsSum; // 计划剩余数量
    @TableField(value="order_nums_sum")
    private java.math.BigDecimal orderNumsSum; // 订单数量
    @TableField(value="deliver_nums_sum")
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    @TableField(value="check_nums_sum")
    private java.math.BigDecimal checkNumsSum; // 验收数量
    @TableField(value="material_manufacturer")
    private java.lang.String materialManufacturer; // 生产厂家
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="source_name")
    private java.lang.String sourceName; // 来源

    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }

    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }

    /**
     * 序号
     */
    public java.lang.String getDetailIndex() {
        return detailIndex;
    }

    /**
     * 序号
     */
    public void setDetailIndex(java.lang.String detailIndex) {
        this.detailIndex = detailIndex;
    }
    /**
     * parent_id
     */
    public java.lang.Long getParentId() {
        return parentId;
    }

    /**
     * parent_id
     */
    public void setParentId(java.lang.Long parentId) {
        this.parentId = parentId;
    }
    /**
     * 是否末级
     */
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 计划主键ID
     */
    public java.lang.Long getPlanId() {
        return planId;
    }

    /**
     * 计划主键ID
     */
    public void setPlanId(java.lang.Long planId) {
        this.planId = planId;
    }
    /**
     * 计划明细主键ID
     */
    public java.lang.Long getPlanDetailId() {
        return planDetailId;
    }

    /**
     * 计划明细主键ID
     */
    public void setPlanDetailId(java.lang.Long planDetailId) {
        this.planDetailId = planDetailId;
    }
    /**
     * 使用计划名称
     */
    public java.lang.String getPlanName() {
        return planName;
    }

    /**
     * 使用计划名称
     */
    public void setPlanName(java.lang.String planName) {
        this.planName = planName;
    }
    /**
     * 计划编码
     */
    public java.lang.String getPlanBillCode() {
        return planBillCode;
    }

    /**
     * 计划编码
     */
    public void setPlanBillCode(java.lang.String planBillCode) {
        this.planBillCode = planBillCode;
    }
    /**
     * 计划编制人
     */
    public java.lang.String getPlanEmployeeName() {
        return planEmployeeName;
    }

    /**
     * 计划编制人
     */
    public void setPlanEmployeeName(java.lang.String planEmployeeName) {
        this.planEmployeeName = planEmployeeName;
    }
    /**
     * 施工部位
     */
    public java.lang.String getConstruction() {
        return construction;
    }

    /**
     * 施工部位
     */
    public void setConstruction(java.lang.String construction) {
        this.construction = construction;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计划数量
     */
    public java.math.BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    /**
     * 计划数量
     */
    public void setPlanNumsSum(java.math.BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }
    /**
     * 接收数量
     */
    public java.math.BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    /**
     * 接收数量
     */
    public void setReceiveNumsSum(java.math.BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    /**
     * 计划剩余数量
     */
    public java.math.BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    /**
     * 计划剩余数量
     */
    public void setSurplusNumsSum(java.math.BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }
    /**
     * 订单数量
     */
    public java.math.BigDecimal getOrderNumsSum() {
        return orderNumsSum;
    }

    /**
     * 订单数量
     */
    public void setOrderNumsSum(java.math.BigDecimal orderNumsSum) {
        this.orderNumsSum = orderNumsSum;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}
